==> wow-opentelemetry-1.15.4-sources.jar: me/ahoo/wow/opentelemetry/snapshot/SnapshotInstrumenter.kt <==
/*
 * Copyright [2021-present] [ahoo wang <ahoowang@qq.com> (https://github.com/Ahoo-Wang)].
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *      http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package me.ahoo.wow.opentelemetry.snapshot

import io.opentelemetry.api.GlobalOpenTelemetry
import io.opentelemetry.instrumentation.api.instrumenter.Instrumenter
import io.opentelemetry.instrumentation.api.instrumenter.SpanNameExtractor
import me.ahoo.wow.event.EventStreamExchange
import me.ahoo.wow.opentelemetry.ExchangeAttributesExtractor
import me.ahoo.wow.opentelemetry.WowInstrumenter
import me.ahoo.wow.opentelemetry.WowInstrumenter.INSTRUMENTATION_NAME_PREFIX
import me.ahoo.wow.opentelemetry.messaging.MessageExchangeTextMapGetter

object SnapshotInstrumenter {
    private const val INSTRUMENTATION_NAME = "${INSTRUMENTATION_NAME_PREFIX}snapshot"
    val INSTRUMENTER: Instrumenter<EventStreamExchange, Unit> =
        Instrumenter.builder<EventStreamExchange, Unit>(
            GlobalOpenTelemetry.get(),
            INSTRUMENTATION_NAME,
            SnapshotSpanNameExtractor,
        ).addAttributesExtractor(ExchangeAttributesExtractor())
            .setInstrumentationVersion(WowInstrumenter.INSTRUMENTATION_VERSION)
            .buildConsumerInstrumenter(MessageExchangeTextMapGetter())
}

object SnapshotSpanNameExtractor : SpanNameExtractor<EventStreamExchange> {
    override fun extract(request: EventStreamExchange): String {
        return "${request.message.aggregateName}.snapshot"
    }
}

==> wow-opentelemetry-3.11.7-sources.jar: me/ahoo/wow/opentelemetry/snapshot/SnapshotInstrumenter.kt <==
/*
 * Copyright [2021-present] [ahoo wang <ahoowang@qq.com> (https://github.com/Ahoo-Wang)].
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *      http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package me.ahoo.wow.opentelemetry.snapshot

import io.opentelemetry.api.GlobalOpenTelemetry
import io.opentelemetry.instrumentation.api.instrumenter.Instrumenter
import io.opentelemetry.instrumentation.api.instrumenter.SpanNameExtractor
import me.ahoo.wow.eventsourcing.state.StateEventExchange
import me.ahoo.wow.opentelemetry.ExchangeAttributesExtractor
import me.ahoo.wow.opentelemetry.WowInstrumenter
import me.ahoo.wow.opentelemetry.WowInstrumenter.INSTRUMENTATION_NAME_PREFIX
import me.ahoo.wow.opentelemetry.messaging.MessageExchangeTextMapGetter

object SnapshotInstrumenter {
    private const val INSTRUMENTATION_NAME = "${INSTRUMENTATION_NAME_PREFIX}snapshot"
    val INSTRUMENTER: Instrumenter<StateEventExchange<*>, Unit> =
        Instrumenter.builder<StateEventExchange<*>, Unit>(
            GlobalOpenTelemetry.get(),
            INSTRUMENTATION_NAME,
            SnapshotSpanNameExtractor,
        ).addAttributesExtractor(ExchangeAttributesExtractor())
            .setInstrumentationVersion(WowInstrumenter.INSTRUMENTATION_VERSION)
            .buildConsumerInstrumenter(MessageExchangeTextMapGetter())
}

object SnapshotSpanNameExtractor : SpanNameExtractor<StateEventExchange<*>> {
    override fun extract(request: StateEventExchange<*>): String {
        return "${request.message.aggregateName}.snapshot"
    }
}
